@@ -11,12 +11,15 @@ if [ $procede = "yes" ]; then
 
   cd docs/
 
+  make latexpdf
   make html
 
   cd build/html/
 
   find . -type f -name "*~" -exec rm -f {} \;
 
+  cp ../latex/pyModis.pdf .
+
   zip -r -9 $curdir/pymodis_${pymodis_version}_html.zip *
 
   cd $curdir
@@ -27,4 +30,4 @@ if [ $procede = "yes" ]; then
 
   python setup.py sdist upload
 
-fi
\ No newline at end of file
+fi
