@@ -26,7 +26,10 @@ import logging
 import socket
 from ftplib import FTP
 import ftplib
-import urllib2
+try:
+    import requests
+except:
+    import urllib2
 from HTMLParser import HTMLParser
 import re
 
@@ -36,7 +39,7 @@ except ImportError:
     try:
         import gdal
     except ImportError:
-        raise('Python GDAL library did not find, please install it')
+        raise('Python GDAL library not found, please install python-gdal')
 
 
 def urljoin(*args):
@@ -78,11 +81,12 @@ class modisHtmlParser(HTMLParser):
     """A class to parse HTML"""
     def __init__(self, fh):
         """
-        {fh} must be an input stream returned by open() or urllib2.urlopen()
+        {fh} must be astring returned by requests.content or
+             urllib2.urlopen().read()
         """
         HTMLParser.__init__(self)
         self.fileids = []
-        self.feed(fh.read())
+        self.feed(fh)
 
     def handle_starttag(self, tag, attrs):
         if tag == 'a':
@@ -140,39 +144,39 @@ class downModis:
 
             destinationFolder = where the files will be stored
 
-            password = the password, should be your email address to use to
-                       connect to FTP server.
-                       Not use this variable if the server is HTPP
+            password = the password, it should be your email address to
+                       connect to a FTP server.
+                       Do not use this variable if the server is a HTTP server
 
-            password = the user, by  default is anonymous, to use to connect
-                       to FTP server.
-                       Not use this variable if the server is HTPP
+            user = the user name, by default 'anonymous', used to connect
+                       to a FTP server.
+                       Do not use this variable if the server is a HTTP server
 
-            url = the url where download the MODIS data, it can be FTP or
-                  HTTP and it have to start with http:// or ftp://
+            url = the url from where to download the MODIS data, it can be FTP or
+                  HTTP and it has to start with http:// or ftp://
 
             path = the directory where the data that you want to download are
-                   stored on the ftp server
+                   stored on the FTP server
 
-            product = the code of product to download, che code should be
-                      ugual to the one of the url
+            product = the code of product to download, the code should be
+                      idential to the one of the url
 
-            tiles = a list of tiles to download, None == all tiles
+            tiles = a list of tiles to be downloaded, None == all tiles
 
             today = the day to start downloading; in order to pass a date
                     different from today use the format YYYY-MM-DD
 
-            enddate = the day to finish downloading; in order to pass a date
+            enddate = the day to end downloading; in order to pass a date
                       use the format YYYY-MM-DD
 
             delta = timelag i.e. the number of days starting from today
                     backwards
 
-            jpeg = set True if you want to download also the jpg file
+            jpeg = set to True if you want to download also the JPG overview file
 
-            debug = set True if you want to obtain debug information
+            debug = set to True if you want to obtain debug information
 
-            timeout = Timeout value for http server
+            timeout = Timeout value for HTTP server
         """
 
         # url modis
@@ -240,10 +244,10 @@ class downModis:
         gdal.UseExceptions()
         gdalDriver = gdal.GetDriverByName('HDF4')
         if not gdalDriver:
-            raise IOError("GDAL has no support for HDF4, please update GDAL")
+            raise IOError("GDAL installation has no support for HDF4, please update GDAL")
 
     def removeEmptyFiles(self):
-        """Check if some file has size ugual 0"""
+        """Check if some file has size equal to 0"""
         year = str(date.today().year)
         pref = self.product.split('.')[0]
         files = glob.glob1(self.writeFilePath, '%s.A%s*' % (pref, year))
@@ -255,7 +259,8 @@ class downModis:
     def connect(self, ncon=20):
         """Connect to the server and fill the dirData variable
 
-           ncon = number maximum of test to connection at the server
+           ncon = maximum number of attempts to connect to the HTTP server
+                  before failing
         """
         if self.urltype == 'ftp':
             self._connectFTP(ncon)
@@ -263,24 +268,24 @@ class downModis:
             self._connectHTTP(ncon)
 
     def _connectHTTP(self, ncon=20):
-        """ Connect to http server, create a list of directories for all days
+        """ Connect to HTTP server, create a list of directories for all days
 
-            ncon = number maximum of test to connection at the ftp server
+            ncon = maximum number of attempts to connect to the HTTP server
+                   before failing
         """
         self.nconnection += 1
         try:
-            http = urllib2.urlopen(urljoin(self.url, self.path),
-                                   timeout=self.timeout)
-        except:
-            logging.error('Error in HTTP connection')
-            if self.nconnection <= ncon:
-                self._connectHTTP()
-        try:
-            self.dirData = modisHtmlParser(http).get_dates()
+            try:
+                http = requests.get(urljoin(self.url, self.path),
+                                    timeout=self.timeout)
+                self.dirData = modisHtmlParser(http.content).get_dates()
+            except:
+                http = urllib2.urlopen(urljoin(self.url, self.path),
+                                       timeout=self.timeout)
+                self.dirData = modisHtmlParser(http.read()).get_dates()
             self.dirData.reverse()
-        except (EOFError, urllib2.URLError), e:
-            logging.error('Error in connection: %s' % e)
-            self.closeHTTP(http)
+        except:
+            logging.error('Error in connection')
             if self.nconnection <= ncon:
                 self._connectHTTP()
 
@@ -288,7 +293,8 @@ class downModis:
         """ Set connection to ftp server, move to path where data are stored
             and create a list of directories for all days
 
-            ncon = number maximum of test to connection at the ftp server
+            ncon = maximum number of attempts to connect to the FTP server
+                   before failing
 
         """
         self.nconnection += 1
@@ -319,16 +325,6 @@ class downModis:
         if self.debug == True:
             logging.debug("Close connection %s" % self.url)
 
-    def closeHTTP(self, http):
-        """ Close http connection
-
-            http = the http concention object created by urlib2.open         
-        """
-        http.close()
-        self.closeFilelist()
-        if self.debug == True:
-            logging.debug("Close connection %s" % self.url)
-
     def closeFilelist(self):
         """ Function to close the file where write the downloaded files """
         self.filelist.close()
@@ -402,8 +398,8 @@ class downModis:
         return self.dirData
 
     def getFilesList(self, day=None):
-        """ Create a list of files to download, it is possible choose to
-            download also the jpeg files or only the hdf files
+        """ Creates a list of files to download, it is possible to choose to
+            download also the JPG overview files or only the HDF files
 
             day = the date of data
 
@@ -414,8 +410,9 @@ class downModis:
             return self._getFilesListFTP()
 
     def _getFilesListHTTP(self, day):
-        """ Create a list of files to download from http server, it is possible
-            choose to download also the jpeg files or only the hdf files
+        """ Creates a list of files to download from http server, it is
+            possible to choose to download also the JPG overview files or
+            only the HDF files
 
             day = the date of data
 
@@ -425,8 +422,12 @@ class downModis:
             url = urljoin(self.url, self.path, day)
             if self.debug == True:
                 logging.debug("The url is: %s" % url)
-            conn = urllib2.urlopen(url)
-            http = modisHtmlParser(conn)
+            try:
+                http = modisHtmlParser(requests.get(url,
+                                       timeout=self.timeout).content)
+            except:
+                http = modisHtmlParser(urllib2.urlopen(url,
+                                       timeout=self.timeout).read())
             # download also jpeg
             if self.jpeg:
                 # finallist is ugual to all file with jpeg file
@@ -443,13 +444,12 @@ class downModis:
                 logging.debug("The number of file to download is: %i" % len(finalList))
             return finalList
         except (socket.error), e:
-            self.closeHTTP(conn)
             logging.error("Error %s when try to receive list of files" % e)
             self._getFilesListHTTP(day)
 
     def _getFilesListFTP(self):
-        """ Create a list of files to download from ftp server, it is possible
-            choose to download also the jpeg files or only the hdf files
+        """ Create a list of files to download from FTP server, it is possible
+            choose to download also the JPG overview files or only the HDF files
         """
         def cicle_file(jpeg=False):
             """Check the type of file"""
@@ -488,7 +488,7 @@ class downModis:
                 logging.debug("The number of file to download is: %i" % len(finalList))
             return finalList
         except (ftplib.error_reply, socket.error), e:
-            logging.error("Error %s when try to receive list of files" % e)
+            logging.error("Error %s when trying to receive list of files" % e)
             self._getFilesListFTP()
 
     def checkDataExist(self, listNewFile, move=0):
@@ -505,13 +505,10 @@ class downModis:
             listOfDifferent = list(set(listNewFile) - set(self.fileInPath))
         elif move == 1:
             listOfDifferent = list(set(self.fileInPath) - set(listNewFile))
-        if self.debug == True:
-                logging.debug("The number of file to download after check of" \
-                              "existing file is: %i" % len(listOfDifferent))
         return listOfDifferent
 
     def checkFile(self, filHdf):
-        """Check using GDAL to be sure that download was fine
+        """Check by using GDAL to be sure that the download went ok
 
         filHdf = name of the HDF file to check
         """
@@ -527,7 +524,7 @@ class downModis:
 
         filDown = name of the file to download
 
-        filHdf = name of the file to write
+        filHdf = name of the file to write to
 
         day = the day in format YYYY.MM.DD
         """
@@ -541,30 +538,33 @@ class downModis:
 
         filDown = name of the file to download
 
-        filSave = name of the file to write
+        filSave = name of the file to write to
 
         day = the day in format YYYY.MM.DD
         """
         filSave = open(filHdf, "wb")
         try:
-            http = urllib2.urlopen(urljoin(self.url, self.path, day, filDown))
-            orig_size = http.headers['content-length']
-            filSave.write(http.read())
+            try:
+                http = requests.get(urljoin(self.url, self.path, day, filDown))
+                orig_size = http.headers['content-length']
+                filSave.write(http.content)
+            except:
+                http = urllib2.urlopen(urljoin(self.url, self.path, day,
+                                               filDown))
+                orig_size = http.headers['content-length']
+                filSave.write(http.read())
             filSave.close()
         #if it have an error it try to download again the file
-        except (EOFError), e:
-            logging.error("Cannot download %s, the error was '%s'. Retry.." % (
-                          filDown, e))
+        except:
+            logging.error("Cannot download %s. Retrying.." % filDown)
             filSave.close()
             os.remove(filSave.name)
-            self.closeHTTP(http)
             self._downloadFileHTTP(filDown, filHdf, day)
         transf_size = os.path.getsize(filSave.name)
         if int(orig_size) == int(transf_size):
             if filHdf.find('.xml') == -1:
                 if self.checkFile(filHdf):
                     os.remove(filSave.name)
-                    self.closeHTTP(http)
                     self._downloadFileHTTP(filDown, filHdf, day)
                 else:
                     self.filelist.write("%s\n" % filDown)
@@ -588,7 +588,7 @@ class downModis:
 
            filDown = name of the file to download
 
-           filSave = name of the file to write
+           filSave = name of the file to write to
         """
         filSave = open(filHdf, "wb")
         try:
@@ -598,7 +598,7 @@ class downModis:
                 logging.debug("File %s downloaded" % filDown)
         #if it have an error it try to download again the file
         except (ftplib.error_reply, socket.error, ftplib.error_temp, EOFError), e:
-            logging.error("Cannot download %s, the error was '%s'. Retry.." % (
+            logging.error("Cannot download %s, the error was '%s'. Retrying..." % (
                           filDown, e))
             filSave.close()
             os.remove(filSave.name)
@@ -644,10 +644,8 @@ class downModis:
                     os.remove(os.path.join(self.writeFilePath, oldFile[0]))
                     file_hdf = os.path.join(self.writeFilePath, fileDown)
             elif numFiles > 1:
-                logging.error("There are to much files for %s" % i)
+                logging.error("There are to many files for %s" % i)
             if numFiles == 0 or (numFiles == 1 and fileDown != oldFile[0]):
-                if self.debug == True:
-                    logging.debug("Start to download file %s" % i)
                 self.downloadFile(i, file_hdf, day)
 
     def downloadsAllDay(self, clean=False, allDays=False):
@@ -655,7 +653,7 @@ class downModis:
 
         filDown = name of the file to download
 
-        filSave = name of the file to write
+        filSave = name of the file to write to
         """
         #return the days to download
         if clean:
